########################################################

# NOTE: Before the code can be excecuted, the R working directory *MUST* 
# be set to the directory that contains the folder 'Online_Appendix_2':

# Remove '#' from the two lines below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'Online_Appendix_2' ( the path 'Z:/here/is/my/path/'
# *MUST* end with a slash / ):

# basedir <- "Z:/here/is/my/path/"
# setwd(basedir)

########################################################


# IDs of data sets used in the comparison study:

dataids2 <- setdiff(c("37", "334", "914", "915", "919", "921", "924", "925", "927", "928", "929", 
             "931", "335", "934", "945", "946", "947", "949", "950", "951", "955", "962", 
             "964", "336", "965", "969", "973", "974", "983", "987", "988", "991", "994", 
             "997", "337", "1005", "1009", "1011", "1013", "1014", "1015", "1016", "1025", 
             "1045", "1048", "346", "1054", "1055", "1059", "1060", "1061", "1062", "1063", 
             "1064", "1065", "1066", "444", "1071", "1073", "1075", "1121", "1441", "1442", 
             "1446", "1447", "1455", "1462", "446", "1463", "1464", "1467", "1473", "1480", 
             "1488", "1490", "1495", "1498", "1510", "448", "1511", "1524", "31", "311", 
             "720", "725", "728", "737", "803", "450", "807", "816", "819", "847", "851", 
             "923", "954", "958", "970", "995", "459", "1021", "1049", "1050", "1067", "1068", 
             "1443", "1444", "1451", "1452", "40", "467", "1453", "1454", "1489", "1494", 
             "1504", "1547", "1570", "44", "312", "472", "316", "735", "761", "476", "971", 
             "976", "978", "980", "1020", "1022", "1042", "479", "1043", "1056", "1069", 
             "1479", "1487", "682", "1038", "1039", "1176", "683", "713", "714", "717", 
             "719", "43", "721", "724", "729", "731", "733", "736", "741", "745", "747", 
             "748", "50", "750", "753", "755", "758", "759", "764", "765", "767", "770", 
             "771", "53", "772", "774", "777", "778", "780", "782", "784", "787", "788", 
             "790", "59", "791", "795", "800", "801", "804", "811", "814", "815", "817", 
             "818", "164", "820", "826", "827", "835", "841", "848", "853", "857", "859", 
             "860", "292", "872", "874", "875", "880", "882", "885", "886", "887", "890", 
             "892", "333", "893", "894", "895", "900", "902", "905", "906", "907", "908", 
             "909"), c("1042", "1038", "1039", "1176"))

	

	
# Load the data sets and extract relevant information:
  
alldatasets <- list.files("./Online_Appendix_2/Data/Datasets")

minprop <- n <- p <- dataid <- propcat <-  0
label <- ""

for(i in seq(along=dataids2)) {
  
  datasetname <- grep(paste("_id", dataids2[i], ".Rda", sep=""), alldatasets, value=TRUE)
  
  load(paste("./Online_Appendix_2/Data/Datasets/", datasetname, sep=""))
  
  classes <- sapply(dataset, class)
  classes <- classes[names(classes)!="Ytarget"]
  
  propcat[i] <- mean(classes=="factor")
  
  minprop[i] <- min(table(dataset$Ytarget))/sum(table(dataset$Ytarget))
  n[i] <- nrow(dataset)
  p[i] <- ncol(dataset) - 1
  
  tempobj <- strsplit(datasetname, split="_")[[1]]
  label[i] <- paste(tempobj[-c(1, length(tempobj))], collapse="_")
  
  dataid[i] <- as.numeric(gsub("id", "", gsub(".Rda", "", tempobj[length(tempobj)])))
  
}
  

  
 
# Make table with information of interest on the data sets: 
 
datatable <- data.frame(data.id=dataid, label=label, n=n, p=p, propcat=propcat, minprop=minprop)
datatable <- datatable[order(datatable$data.id),]

datatable$label <- as.character(datatable$label)

rownames(datatable) <- NULL

datatable2 <- datatable
datatable2$propcat <- round(datatable2$propcat, 3)
datatable2$minprop <- round(datatable2$minprop, 3)

datatable2$propcat <- format(datatable2$propcat, nsmall=3)
datatable2$minprop <- format(datatable2$minprop, nsmall=3)






# Make LaTeX commands needed to present the tables that show the information
# on the data sets in the supplement:

tabletext <- ""

for(i in 1:nrow(datatable2))
  tabletext[i] <- paste(paste(datatable2[i,], collapse=" & "), " \\\\", sep="")


tabstart <- c("\\begin{table}[!htb]",
              "\\begin{tabular}{l | l | l | l | l | l}",
              "data.id & label & n & p & prop. categ. & prop. min. class \\\\",
              "\\hline")


tabend <- c("\\end{tabular}",
            "\\caption{Overview of data sets -- I. The following information is provided: `data.id': OpenML ID of the data set, `label': data set label, `n': sample size, `p': number of covariates, `prop. categ.': proportion of categorial covariates, `prop. min. class': proportion of observations in the smaller class of the target variable}",
            "\\label{tab:data1}",
            "\\end{table}")


tabletexttemp <- tabletext[1:43]

tabtemp <- c(tabstart, tabletexttemp, tabend)

for(i in seq(along=tabtemp))
  cat(tabtemp[i], "\n")



tabletexttemp <- tabletext[43 + (1:45)]

tabtemp <- c(tabstart, tabletexttemp, tabend)

for(i in seq(along=tabtemp))
  cat(tabtemp[i], "\n")



tabletexttemp <- tabletext[43 + 45 + (1:45)]

tabtemp <- c(tabstart, tabletexttemp, tabend)

for(i in seq(along=tabtemp))
  cat(tabtemp[i], "\n")



tabletexttemp <- tabletext[43 + 2*45 + (1:45)]

tabtemp <- c(tabstart, tabletexttemp, tabend)

for(i in seq(along=tabtemp))
  cat(tabtemp[i], "\n")



tabletexttemp <- tabletext[(43 + 3*45 + 1):220]

tabtemp <- c(tabstart, tabletexttemp, tabend)

for(i in seq(along=tabtemp))
  cat(tabtemp[i], "\n")
