########################################################

# NOTE: Before the code can be excecuted, the R working directory *MUST* 
# be set to the directory that contains the folder 'Online_Appendix_2':

# Remove '#' from the two lines below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'Online_Appendix_2' ( the path 'Z:/here/is/my/path/'
# *MUST* end with a slash / ):

# basedir <- "Z:/here/is/my/path/"
# setwd(basedir)

########################################################


# Load and process results:


load("./Online_Appendix_2/Results/DetermineTuningGrid/scenariogrid.Rda")
load("./Online_Appendix_2/Results/DetermineTuningGrid/Results_DetermineTuningGrid.Rda")
load("./Online_Appendix_2/Data/datainfo.Rda")


reorderind <- order(scenariogrid$dataid, scenariogrid$cvind, scenariogrid$nmaxsplits, scenariogrid$proptry)

scenariogrid <- scenariogrid[reorderind,]
rownames(scenariogrid) <- NULL

Results <- Results[reorderind]



Resultssafe <- Results

Results <- list()
count <- 1

for(i in seq(along=Resultssafe)) {
  for(j in 1:length(Resultssafe[[i]])) {
    Results[[count]] <- Resultssafe[[i]][[j]]
    count <- count + 1
  }
}



scenariogrid$n <- sapply(scenariogrid$dataid, function(x) datainfo$n[datainfo$dataid==x])
scenariogrid$p <- sapply(scenariogrid$dataid, function(x) datainfo$p[datainfo$dataid==x])

scenariogrid <- scenariogrid[rep(1:nrow(scenariogrid), each=5),]
scenariogrid$cviter <- rep(1:5, times=nrow(scenariogrid)/5)



resultsall <- scenariogrid

resultsall$acc <- sapply(Results, function(x) x$acctest)
resultsall$auc <- sapply(Results, function(x) x$auctest)
resultsall$brier <- sapply(Results, function(x) x$briertest)



library("plyr")
resultssum <- ddply(resultsall, .variables=c("dataid", "nmaxsplits", "proptry", "n", "p"), .fun=summarise, acc=mean(acc), auc=mean(auc), brier=mean(brier))

resultssum$dataset <- paste("ID: ", resultssum$dataid, ", n = ", resultssum$n, ", p = ", resultssum$p, sep="")


datasets <- unique(resultssum$dataset)
datasets <- datasets[order(as.numeric(sapply(datasets, function(x) strsplit(strsplit(x, split="ID: ")[[1]][2], split=",")[[1]][1])))]



resultssum$nmaxsplits <- factor(resultssum$nmaxsplits)

names(resultssum)[names(resultssum)=="auc"] <- "AUC"
names(resultssum)[names(resultssum)=="nmaxsplits"] <- "nsplits"








# Figures: Pre-study: Cross-validated AUC values obtained for the different parameter values:


library("ggplot2")
p <- ggplot(data=resultssum[resultssum$dataset %in% datasets[1:18],], aes(x=proptry, y=AUC, color=nsplits)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_AllResults_1.pdf", width=7.5, height=10)


p <- ggplot(data=resultssum[resultssum$dataset %in% datasets[19:36],], aes(x=proptry, y=AUC, color=nsplits)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_AllResults_2.pdf", width=7.5, height=10)


p <- ggplot(data=resultssum[resultssum$dataset %in% datasets[37:50],], aes(x=proptry, y=AUC, color=nsplits)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_AllResults_3.pdf", width=7.5, height=10*(5/6))








# Figures: Pre-study: Cross-validated AUC values obtained for different nsplits values:


resultssum2 <- ddply(resultssum, .variables=c("dataset", "nsplits", "n", "p"), .fun=summarise, AUC=max(AUC), brier=min(brier))


p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[1:18],], aes(x=as.numeric(as.character(nsplits)), y=AUC)) + xlab("nsplits") + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_nsplits_1.pdf", width=7.5, height=10)



p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[19:36],], aes(x=as.numeric(as.character(nsplits)), y=AUC)) + xlab("nsplits") + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_nsplits_2.pdf", width=7.5, height=10)



p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[37:50],], aes(x=as.numeric(as.character(nsplits)), y=AUC)) + xlab("nsplits") + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_nsplits_3.pdf", width=7.5, height=10*(5/6))








# Figures: Pre-study: Cross-validated AUC values obtained for different proptry values:


resultssum2 <- ddply(resultssum, .variables=c("dataset", "proptry", "n", "p"), .fun=summarise, AUC=max(AUC), brier=min(brier))


p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[1:18],], aes(x=proptry, y=AUC)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_proptry_1.pdf", width=7.5, height=10)



p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[19:36],], aes(x=proptry, y=AUC)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_proptry_2.pdf", width=7.5, height=10)



p <- ggplot(data=resultssum2[resultssum2$dataset %in% datasets[37:50],], aes(x=proptry, y=AUC)) + theme_bw() + geom_point() + geom_line() + facet_wrap(~ dataset, ncol=3, scales="free_y") + ylab("cross-validated AUC")
p

ggsave("./Online_Appendix_2/Results/Figures/TuningStudy_proptry_3.pdf", width=7.5, height=10*(5/6))
