########################################################

# NOTE: Before the code can be excecuted, the R working directory *MUST* 
# be set to the directory that contains the folder 'Online_Appendix_2':

# Remove '#' from the two lines below and replace 'Z:/here/is/my/path/' by the path
# to the directory that contains 'Online_Appendix_2' ( the path 'Z:/here/is/my/path/'
# *MUST* end with a slash / ):

# basedir <- "Z:/here/is/my/path/"
# setwd(basedir)

########################################################


# Load and process results:


load("./Online_Appendix_2/Results/LargeStudy/scenariogrid.Rda")
load("./Online_Appendix_2/Results/LargeStudy/Results_LargeStudy.Rda")
load("./Online_Appendix_2/Data/datainfo.Rda")


reorderind <- order(scenariogrid$dataid, scenariogrid$cvind, scenariogrid$method)

scenariogrid <- scenariogrid[reorderind,]
rownames(scenariogrid) <- NULL

Results <- Results[reorderind]



Resultssafe <- Results

Results <- list()
count <- 1

for(i in seq(along=Resultssafe)) {
  for(j in 1:length(Resultssafe[[i]])) {
    Results[[count]] <- Resultssafe[[i]][[j]]
    count <- count + 1
  }
}




scenariogrid$n <- sapply(scenariogrid$dataid, function(x) datainfo$n[datainfo$dataid==x])
scenariogrid$p <- sapply(scenariogrid$dataid, function(x) datainfo$p[datainfo$dataid==x])


scenariogrid <- scenariogrid[rep(1:nrow(scenariogrid), each=5),]
scenariogrid$cviter <- rep(1:5, times=nrow(scenariogrid)/5)


scenariogrid$method <- factor(scenariogrid$method, levels=c("df", "rf", "rfextratrees1", "rfextratrees5"))



resultsall <- scenariogrid

resultsall$acc  <- sapply(Results, function(x) x$acctest)
resultsall$auc <- sapply(Results, function(x) x$auctest)
resultsall$brier <- sapply(Results, function(x) x$briertest)



resultsall$method <- as.character(resultsall$method)
resultsall$method[resultsall$method=="df"] <- "DF"
resultsall$method[resultsall$method=="rf"] <- "RF"
resultsall$method[resultsall$method=="rfextratrees1"] <- "RFextr1"
resultsall$method[resultsall$method=="rfextratrees5"] <- "RFextr5"
resultsall$method <- factor(resultsall$method, levels=c("RF", "DF", "RFextr1", "RFextr5"))



resultsall$paramopt <- sapply(Results, function(x) x$paramopt)


library("plyr")
resultssum <- ddply(resultsall, .variables=c("dataid", "cvind", "method", "n", "p"), .fun=summarise, acc=mean(acc), auc=mean(auc), brier=mean(brier), paramopt=median(paramopt))
resultssum2 <- ddply(resultssum, .variables=c("dataid", "method", "n", "p"), .fun=summarise, acc=mean(acc), auc=mean(auc), brier=mean(brier), paramopt=median(paramopt))

resultswide <- reshape(resultssum2, idvar = c("dataid", "n", "p"), timevar = "method", direction = "wide")









# Figure of the method-specific quartiles of the different performance measures calculated per data set
# (this figure is not shown in the paper, but these values are shown in Table 1):


quantilestemp <- c(unlist(tapply(resultssum2$acc, resultssum2$method, quantile, probs=c(0.25, 0.5, 0.75))),
                   unlist(tapply(resultssum2$auc, resultssum2$method, quantile, probs=c(0.25, 0.5, 0.75))),
                   unlist(tapply(resultssum2$brier, resultssum2$method, quantile, probs=c(0.25, 0.5, 0.75))))
quantilestemp

datatemp <- data.frame(value=quantilestemp)
datatemp$method <- rep(rep(c("RF", "DF", "RFextr1", "RFextr5"), each=3), times=3)
datatemp$method <- factor(datatemp$method, levels=c("RF", "DF", "RFextr1", "RFextr5"))
datatemp$quantile <- rep(c(0.25, 0.50, 0.75), times=3*4)
datatemp$measure <- rep(c("ACC", "AUC", "Brier"), each=3*4)

datatemp


datatemp1 <- datatemp[datatemp$measure=="ACC",]
datatemp2 <- reshape(datatemp1[datatemp1$quantile %in% c(0.25, 0.75),], idvar = c("method", "measure"), timevar = "quantile", direction = "wide")
names(datatemp2)[names(datatemp2)=="value.0.25"] <- "Q25"
names(datatemp2)[names(datatemp2)=="value.0.75"] <- "Q75"

library("ggplot2")

p1 <- ggplot(data=datatemp1, aes(x=method)) + theme_bw() + 
  geom_point(data=datatemp1[datatemp1$quantile==0.5,], aes(y=value)) +
  geom_errorbar(data=datatemp2, aes(ymin=Q25, ymax=Q75))


datatemp1 <- datatemp[datatemp$measure=="AUC",]
datatemp2 <- reshape(datatemp1[datatemp1$quantile %in% c(0.25, 0.75),], idvar = c("method", "measure"), timevar = "quantile", direction = "wide")
names(datatemp2)[names(datatemp2)=="value.0.25"] <- "Q25"
names(datatemp2)[names(datatemp2)=="value.0.75"] <- "Q75"

p2 <- ggplot(data=datatemp1, aes(x=method)) + theme_bw() + 
  geom_point(data=datatemp1[datatemp1$quantile==0.5,], aes(y=value)) +
  geom_errorbar(data=datatemp2, aes(ymin=Q25, ymax=Q75))


datatemp1 <- datatemp[datatemp$measure=="Brier",]
datatemp2 <- reshape(datatemp1[datatemp1$quantile %in% c(0.25, 0.75),], idvar = c("method", "measure"), timevar = "quantile", direction = "wide")
names(datatemp2)[names(datatemp2)=="value.0.25"] <- "Q25"
names(datatemp2)[names(datatemp2)=="value.0.75"] <- "Q75"

p3 <- ggplot(data=datatemp1, aes(x=method)) + theme_bw() + 
  geom_point(data=datatemp1[datatemp1$quantile==0.5,], aes(y=value)) +
  geom_errorbar(data=datatemp2, aes(ymin=Q25, ymax=Q75))


library("grid")
library("gridExtra")
pall <- grid.arrange(p1, p2, p3, nrow = 1)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/FigureErrorBars.pdf", plot=pall, width=14, height=7)






# Table 1 in the paper:

datatempwide <- reshape(datatemp, idvar = c("method", "measure"), timevar = "quantile", direction = "wide")

datatempwide2 <- datatempwide
datatempwide2[,-(1:2)] <- round(datatempwide2[,-(1:2)], 4)

datatempwide2$method <- factor(datatempwide2$method, levels=c("RF", "DF", "RFextr1", "RFextr5"))

datatempwide2 <- datatempwide2[order(datatempwide2$measure, datatempwide2$method),]

datatempwide2







# Wilcoxon tests used to test, whether the slight improvements of DF, RFextr1, and RFextr5 over RF with respect to the three measure are statistically significant.
# In the case of DF the 50 data sets that had been used in the pre-study for determining suitable grids for the tuning parameter values were excluded.


dataidssample <- c("974", "1511", "736", "1021", "467", "1487", "1043", "53", "43", 
                   "479", "970", "1050", "807", "1464", "448", "1504", "934", "971", 
                   "814", "1441", "915", "893", "733", "1014", "875", "853", "847", 
                   "316", "900", "1455", "788", "774", "735", "1055", "1451", "1022", 
                   "737", "1015", "1494", "1473", "759", "1016", "1025", "334", "1547", 
                   "886", "1059", "1049", "1061", "1056")

resultswidetemp <- resultswide[!(resultswide$dataid %in% dataidssample),]

wilcox.test(resultswidetemp$acc.DF, resultswidetemp$acc.RF, paired=TRUE)$p.value
wilcox.test(resultswidetemp$auc.DF, resultswidetemp$auc.RF, paired=TRUE)$p.value
wilcox.test(resultswidetemp$brier.DF, resultswidetemp$brier.RF, paired=TRUE)$p.value

wilcox.test(resultswide$acc.DF, resultswide$acc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$auc.DF, resultswide$auc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$brier.DF, resultswide$brier.RF, paired=TRUE)$p.value


wilcox.test(resultswide$acc.RFextr1, resultswide$acc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$auc.RFextr1, resultswide$auc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$brier.RFextr1, resultswide$brier.RF, paired=TRUE)$p.value


wilcox.test(resultswide$acc.RFextr5, resultswide$acc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$auc.RFextr5, resultswide$auc.RF, paired=TRUE)$p.value
wilcox.test(resultswide$brier.RFextr5, resultswide$brier.RF, paired=TRUE)$p.value











# Figure: Data set specific performances of DF compared to that of RF.

datatemp1 <- data.frame(diffDFRF=resultswide$acc.DF - resultswide$acc.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffDFRF)) + theme_bw() + geom_histogram(binwidth=0.005) + geom_vline(xintercept=0, color=2) + 
  theme(axis.title=element_text(size=13)) +
  xlab("Differences between data set specific\nACC values obtained for DF and for RF")


datatemp2 <- data.frame(accRF=resultswide$acc.RF,accdiffDF=resultswide$acc.DF - resultswide$acc.RF) 

p2 <- ggplot(data=datatemp2, aes(x=accRF, y=accdiffDF)) + theme_bw() + geom_point(size=0.5) + 
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE) + labs(x="Data set specific ACC values obtained for RF", 
                                                                     y="Differences between data set specific\nACC values obtained for DF and for RF")

pall <- grid.arrange(p1, p2, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF.pdf", plot=pall, width=10, height=5)







# Figure: Data set specific performances of RFextr1 and RFextr5 compared to that of RF.

datatemp1 <- data.frame(diffRFextra1RF=resultswide$acc.RFextr1 - resultswide$acc.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nACC values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_vline(xintercept=0, color=2)


datatemp2 <- data.frame(accRF=resultswide$acc.RF, accdiffRFextr1=resultswide$acc.RFextr1 - resultswide$acc.RF) 

p2 <- ggplot(data=datatemp2, aes(x=accRF, y=accdiffRFextr1)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific ACC values obtained for RF",
       y="Differences between data set specific\nACC values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


datatemp3 <- data.frame(diffRFextra1RF=resultswide$acc.RFextr5 - resultswide$acc.RF)

p3 <- ggplot(data=datatemp3, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nACC values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_vline(xintercept=0, color=2)


datatemp4 <- data.frame(accRF=resultswide$acc.RF, accdiffRFextr5=resultswide$acc.RFextr5 - resultswide$acc.RF) 

p4 <- ggplot(data=datatemp4, aes(x=accRF, y=accdiffRFextr5)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific ACC values obtained for RF",
       y="Differences between data set specific\nACC values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF_Supplement.pdf", plot=pall, width=10, height=10)








# Figure: Influence of sample size n and number of covariates p on the performance of DF and RF.


library("asbio")

myloesssurf <- function (Y, X, span = 0.75, degree = 1, family = "gaussian", 
                         phi = 20, theta = 50, xlab = "X", ylab = "Y", 
                         zlab = "Fit", line.col = 1, line.type = 1, scale = TRUE, 
                         duplicate = "error", expand = 0.5, ...) 
{
  lom <- loess(Y ~ X, span = span, degree = degree, family = family)
  r <- ncol(lom$x)
  yhat <- lom$fitted
  if (r > 2) 
    stop("Number of predictors must be < 2")
  if (r == 1) {
    plot(X, Y, xlab = xlab, ylab = ylab, ...)
    d <- 10^round(log(min(X), 10), 0)
    xv <- seq(min(X), max(X), d/100)
    yv <- predict(lom, data.frame(X = xv))
    lines(xv, yv, col = line.col, lty = line.type)
  }
  if (r == 2) {
    iout <- c(1:length(yhat))
    nm1 <- length(yhat) - 1
    for (i in 1:nm1) {
      ip1 <- i + 1
      for (k in ip1:length(yhat)) if (sum(X[i, ] == X[k, 
                                                      ]) == 2) 
        iout[k] <- 0
    }
    yhat1 <- yhat[iout >= 1]
    X1 <- X[iout >= 1, ]
    interp <- NA
    rm(interp)
    fit <- akima::interp(X1[, 1], X1[, 2], yhat1, duplicate = duplicate)
    # persp(fit, theta = theta, phi = phi, xlab = xlab, ylab = ylab, 
    # zlab = zlab, scale = scale, expand = expand)
  }
}

environment(myloesssurf) <- environment(loess.surf)




datatemp <- resultssum2[resultssum2$method %in% c("DF", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(n)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")

p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$acc.DF - resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$accdiff <- as.vector(accdiff)

library("viridis")

p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = accdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific ACC\nvalues obtained\nfor DF and for RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$acc.DF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffDF <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), acc=unlist(lapply(1:length(qus), function(x) c(accdiffRF[which.min(abs(res$logn-qus[x])),], accdiffDF[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "DF"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=acc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("black", "red")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics.pdf", plot=pall, width=11.5, height=9.5)






# Figure: Influence of sample size n and number of covariates p on the performance of RFextr1 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr1", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(n)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$acc.RFextr1 - resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$accdiff <- as.vector(accdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = accdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific ACC\nvalues obtained\nfor RFextr1 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$acc.RFextr1,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffRFextr1 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), acc=unlist(lapply(1:length(qus), function(x) c(accdiffRF[which.min(abs(res$logn-qus[x])),], accdiffRFextr1[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr1"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=acc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr1.pdf", plot=pall, width=11, height=10)








# Figure: Influence of sample size n and number of covariates p on the performance of RFextr5 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr5", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(n)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=acc), size=0.5) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=acc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$acc.RFextr5 - resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$accdiff <- as.vector(accdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = accdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific ACC\nvalues obtained\nfor RFextr5 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$acc.RFextr5,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffRFextr5 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$acc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
accdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), acc=unlist(lapply(1:length(qus), function(x) c(accdiffRF[which.min(abs(res$logn-qus[x])),], accdiffRFextr5[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr5"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=acc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific ACC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr5.pdf", plot=pall, width=11, height=10)








# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot() # + geom_line(aes(group=dataid), color="grey")

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$accRF <- sapply(resultstemp$dataid, function(x) resultstemp2$acc[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=accRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific ACC values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry.pdf", plot=pall, width=11.5, height=9.5)





# Correlation between the logarithmized sample sizes and the
# logarithmized number of covariates:

cor(log(resultswide$n), log(resultswide$p))






# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities - excluding data set '312'.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstempsafe <- resultstemp
resultstempsafe[log(resultstempsafe$p) >= 5.5,]

resultswide[resultswide$dataid==resultstempsafe[log(resultstempsafe$p) >= 5.5,]$dataid[1],]


resultstemp <- resultstemp[log(resultstemp$p) < 5.5,]

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot() # + geom_line(aes(group=dataid), color="grey")

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)
p3

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$accRF <- sapply(resultstemp$dataid, function(x) resultstemp2$acc[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=accRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific ACC values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry_2.pdf", plot=pall, width=11.5, height=9.5)







# Figure: Relationships between the mtry values selected by RF, RFextr1, and RFextr5 
# and the logarithmized values of the sample size stratified according to the numbers 
# of covariates in the data sets.

quantile(resultswide$p, (1:9)/10)

mean(resultswide$p <= 5)
mean((resultswide$p > 5) & (resultswide$p <= 15))
mean(resultswide$p > 15)

sum(resultswide$p <= 5)
sum((resultswide$p > 5) & (resultswide$p <= 15))
sum(resultswide$p > 15)


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstemp3 <- resultstemp
head(resultstemp3)
resultstemp3$psize <- "Small p"
resultstemp3$psize[resultstemp3$p > 5] <- "Middle p"
resultstemp3$psize[resultstemp3$p > 15] <- "Large p"
resultstemp3$psize <- factor(resultstemp3$psize, levels=c("Small p", "Middle p", "Large p"))

p <- ggplot(data=resultstemp3, aes(x=log(n), y=paramopt/p)) + theme_bw() + geom_point(aes(color=method)) + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10), strip.text = element_text(size=12), legend.position = "none") +
  geom_smooth(aes(color=method), se=FALSE) + facet_wrap(~ psize, nrow=1)
p

ggsave(file="./Online_Appendix_2/Results/Figures/InfluenceNstratified.pdf", width=10, height=5)







# Figure: Relationships between the selected proptry values and various quantities.

resultstemp <- resultsall[resultsall$method=="DF",]
resultstemp <- ddply(resultstemp, .variables=c("dataid", "n", "p"), .fun=summarise, paramopt=median(paramopt))

resultswide$paramoptDF <- sapply(resultswide$dataid, function(x) resultstemp$paramopt[resultstemp$dataid==x])

table(resultswide$paramoptDF)

p1 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(n))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p2 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(p))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p3 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=acc.RF)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("Data set specific ACC values obtained for RF")

p4 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=paramopt.RF/p)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("mtry/p")

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Proptry.pdf", plot=pall, width=11.5, height=9.5)

















# Figures "CompRF.pdf", "CompRF_Supplement.pdf", "DataCharacteristics.pdf", "DataCharacteristics_RFextr1.pdf", 
# "DataCharacteristics_RFextr5.pdf", "Mtry.pdf", "Mtry_2.pdf", "InfluenceNstratified.pdf", and "Proptry.pdf" 
# (see above) replacing the ACC by the AUC as performance measure.
#############################################################################################################


# Figure: Data set specific performances of DF compared to that of RF.

datatemp1 <- data.frame(diffDFRF=resultswide$auc.DF - resultswide$auc.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffDFRF)) + theme_bw() + geom_histogram(binwidth=0.005) + geom_vline(xintercept=0, color=2) + 
  theme(axis.title=element_text(size=13)) +
  xlab("Differences between data set specific\nAUC values obtained for DF and for RF")


datatemp2 <- data.frame(aucRF=resultswide$auc.RF,aucdiffDF=resultswide$auc.DF - resultswide$auc.RF) 

p2 <- ggplot(data=datatemp2, aes(x=aucRF, y=aucdiffDF)) + theme_bw() + geom_point(size=0.5) + 
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE) + labs(x="Data set specific AUC values obtained for RF", 
                                                                     y="Differences between data set specific\nAUC values obtained for DF and for RF")

pall <- grid.arrange(p1, p2, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF_auc.pdf", plot=pall, width=10, height=5)







# Figure: Data set specific performances of RFextr1 and RFextr5 compared to that of RF.

datatemp1 <- data.frame(diffRFextra1RF=resultswide$auc.RFextr1 - resultswide$auc.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nAUC values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_vline(xintercept=0, color=2)


datatemp2 <- data.frame(aucRF=resultswide$auc.RF, aucdiffRFextr1=resultswide$auc.RFextr1 - resultswide$auc.RF) 

p2 <- ggplot(data=datatemp2, aes(x=aucRF, y=aucdiffRFextr1)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific AUC values obtained for RF",
       y="Differences between data set specific\nAUC values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


datatemp3 <- data.frame(diffRFextra1RF=resultswide$auc.RFextr5 - resultswide$auc.RF)

p3 <- ggplot(data=datatemp3, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nAUC values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_vline(xintercept=0, color=2)


datatemp4 <- data.frame(aucRF=resultswide$auc.RF, aucdiffRFextr5=resultswide$auc.RFextr5 - resultswide$auc.RF) 

p4 <- ggplot(data=datatemp4, aes(x=aucRF, y=aucdiffRFextr5)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific AUC values obtained for RF",
       y="Differences between data set specific\nAUC values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF_Supplement_auc.pdf", plot=pall, width=10, height=10)







# Figure: Influence of sample size n and number of covariates p on the performance of DF and RF.

datatemp <- resultssum2[resultssum2$method %in% c("DF", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(n)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")

p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$auc.DF - resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$aucdiff <- as.vector(aucdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = aucdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific auc\nvalues obtained\nfor DF and for RF")) +
  scale_fill_viridis() 



quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$auc.DF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffDF <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), auc=unlist(lapply(1:length(qus), function(x) c(aucdiffRF[which.min(abs(res$logn-qus[x])),], aucdiffDF[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "DF"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=auc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("black", "red")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_auc.pdf", plot=pall, width=11, height=10)







# Figure: Influence of sample size n and number of covariates p on the performance of RFextr1 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr1", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(n)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$auc.RFextr1 - resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$aucdiff <- as.vector(aucdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = aucdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific auc\nvalues obtained\nfor RFextr1 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$auc.RFextr1,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffRFextr1 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), auc=unlist(lapply(1:length(qus), function(x) c(aucdiffRF[which.min(abs(res$logn-qus[x])),], aucdiffRFextr1[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr1"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=auc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr1_auc.pdf", plot=pall, width=11, height=10)








# Figure: Influence of sample size n and number of covariates p on the performance of RFextr5 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr5", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(n)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=auc), size=0.5) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=auc), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$auc.RFextr5 - resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$aucdiff <- as.vector(aucdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = aucdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific auc\nvalues obtained\nfor RFextr5 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$auc.RFextr5,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffRFextr5 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$auc.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
aucdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), auc=unlist(lapply(1:length(qus), function(x) c(aucdiffRF[which.min(abs(res$logn-qus[x])),], aucdiffRFextr5[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr5"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=auc)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific AUC values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr5_auc.pdf", plot=pall, width=11, height=10)








# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot()

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$aucRF <- sapply(resultstemp$dataid, function(x) resultstemp2$auc[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=aucRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific AUC values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry_auc.pdf", plot=pall, width=11, height=10)







# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities - excluding data set '312'.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstempsafe <- resultstemp


resultstemp <- resultstemp[log(resultstemp$p) < 5.5,]

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot()

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$aucRF <- sapply(resultstemp$dataid, function(x) resultstemp2$auc[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=aucRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific AUC values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry_2_auc.pdf", plot=pall, width=11, height=10)






# Figure: Relationships between the mtry values selected by RF, RFextr1, and RFextr5 
# and the logarithmized values of the sample size stratified aucording to the numbers 
# of covariates in the data sets.

quantile(resultswide$p, (1:9)/10)

mean(resultswide$p <= 5)
mean((resultswide$p > 5) & (resultswide$p <= 15))
mean(resultswide$p > 15)

sum(resultswide$p <= 5)
sum((resultswide$p > 5) & (resultswide$p <= 15))
sum(resultswide$p > 15)


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstemp3 <- resultstemp
head(resultstemp3)
resultstemp3$psize <- "Small p"
resultstemp3$psize[resultstemp3$p > 5] <- "Middle p"
resultstemp3$psize[resultstemp3$p > 15] <- "Large p"
resultstemp3$psize <- factor(resultstemp3$psize, levels=c("Small p", "Middle p", "Large p"))

p <- ggplot(data=resultstemp3, aes(x=log(n), y=paramopt/p)) + theme_bw() + geom_point(aes(color=method)) + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10), strip.text = element_text(size=12), legend.position = "none") +
  geom_smooth(aes(color=method), se=FALSE) + facet_wrap(~ psize, nrow=1)
p

ggsave(file="./Online_Appendix_2/Results/Figures/InfluenceNstratified_auc.pdf", width=10, height=5)






# Figure: Relationships between the selected proptry values and various quantities.

resultstemp <- resultsall[resultsall$method=="DF",]
resultstemp <- ddply(resultstemp, .variables=c("dataid", "n", "p"), .fun=summarise, paramopt=median(paramopt))

resultswide$paramoptDF <- sapply(resultswide$dataid, function(x) resultstemp$paramopt[resultstemp$dataid==x])


table(resultswide$paramoptDF)


p1 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(n))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p2 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(p))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p3 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=auc.RF)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("Data set specific AUC values obtained for RF")

p4 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=paramopt.RF/p)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("mtry/p")

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Proptry_auc.pdf", plot=pall, width=11, height=10)

















# Figures "CompRF.pdf", "CompRF_Supplement.pdf", "DataCharacteristics.pdf", "DataCharacteristics_RFextr1.pdf", 
# "DataCharacteristics_RFextr5.pdf", "Mtry.pdf", "Mtry_2.pdf", "InfluenceNstratified.pdf", and "Proptry.pdf" 
# (see above) replacing the ACC by the Brier as performance measure.
#############################################################################################################


# Figure: Data set specific performances of DF compared to that of RF.

datatemp1 <- data.frame(diffDFRF=resultswide$brier.DF - resultswide$brier.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffDFRF)) + theme_bw() + geom_histogram(binwidth=0.005) + geom_vline(xintercept=0, color=2) + 
  theme(axis.title=element_text(size=13)) +
  xlab("Differences between data set specific\nBrier values obtained for DF and for RF")


datatemp2 <- data.frame(brierRF=resultswide$brier.RF,brierdiffDF=resultswide$brier.DF - resultswide$brier.RF) 

p2 <- ggplot(data=datatemp2, aes(x=brierRF, y=brierdiffDF)) + theme_bw() + geom_point(size=0.5) + 
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE) + labs(x="Data set specific Brier values obtained for RF", 
                                                                     y="Differences between data set specific\nBrier values obtained for DF and for RF")

pall <- grid.arrange(p1, p2, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF_brier.pdf", plot=pall, width=10, height=5)







# Figure: Data set specific performances of RFextr1 and RFextr5 compared to that of RF.

datatemp1 <- data.frame(diffRFextra1RF=resultswide$brier.RFextr1 - resultswide$brier.RF)

p1 <- ggplot(data=datatemp1, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nBrier values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_vline(xintercept=0, color=2)


datatemp2 <- data.frame(brierRF=resultswide$brier.RF, brierdiffRFextr1=resultswide$brier.RFextr1 - resultswide$brier.RF) 

p2 <- ggplot(data=datatemp2, aes(x=brierRF, y=brierdiffRFextr1)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific Brier values obtained for RF",
       y="Differences between data set specific\nBrier values obtained for RFextr1 and for RF") +
  theme(axis.title=element_text(size=13)) +
  geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


datatemp3 <- data.frame(diffRFextra1RF=resultswide$brier.RFextr5 - resultswide$brier.RF)

p3 <- ggplot(data=datatemp3, aes(x=diffRFextra1RF)) + theme_bw() + geom_histogram(binwidth=0.005) + 
  xlab("Differences between data set specific\nBrier values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_vline(xintercept=0, color=2)


datatemp4 <- data.frame(brierRF=resultswide$brier.RF, brierdiffRFextr5=resultswide$brier.RFextr5 - resultswide$brier.RF) 

p4 <- ggplot(data=datatemp4, aes(x=brierRF, y=brierdiffRFextr5)) + theme_bw() + geom_point(size=0.5) + 
  labs(x="Data set specific Brier values obtained for RF",
       y="Differences between data set specific\nBrier values obtained for RFextr5 and for RF") +
  theme(axis.title=element_text(size=13)) + geom_hline(yintercept = 0, color=2) + geom_smooth(se=FALSE)


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/CompRF_Supplement_brier.pdf", plot=pall, width=10, height=10)








# Figure: Influence of sample size n and number of covariates p on the performance of DF and RF.

datatemp <- resultssum2[resultssum2$method %in% c("DF", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(n)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")

p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$brier.DF - resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$brierdiff <- as.vector(brierdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = brierdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific brier\nvalues obtained\nfor DF and for RF")) +
  scale_fill_viridis() 



quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$brier.DF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffDF <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), brier=unlist(lapply(1:length(qus), function(x) c(brierdiffRF[which.min(abs(res$logn-qus[x])),], brierdiffDF[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "DF"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=brier)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("black", "red")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_brier.pdf", plot=pall, width=11, height=10)







# Figure: Influence of sample size n and number of covariates p on the performance of RFextr1 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr1", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(n)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$brier.RFextr1 - resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$brierdiff <- as.vector(brierdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = brierdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific brier\nvalues obtained\nfor RFextr1 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$brier.RFextr1,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffRFextr1 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), brier=unlist(lapply(1:length(qus), function(x) c(brierdiffRF[which.min(abs(res$logn-qus[x])),], brierdiffRFextr1[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr1"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=brier)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr1_brier.pdf", plot=pall, width=11, height=10)








# Figure: Influence of sample size n and number of covariates p on the performance of RFextr5 and RF.


datatemp <- resultssum2[resultssum2$method %in% c("RFextr5", "RF"),]

p1 <- ggplot(data=datatemp, aes(x=log(n), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(n)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


p2 <- ggplot(data=datatemp, aes(x=log(p), color=method)) + theme_bw() + geom_point(aes(y=brier), size=0.5) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10)) +
  geom_smooth(aes(y=brier), se=FALSE, size=0.5) + scale_color_manual(values=c("red", "black")) + theme(legend.position = "none")


loesssurvres <- myloesssurf(resultswide$brier.RFextr5 - resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiff <- loesssurvres$z

datatemp2 <- expand.grid(logn=res$logn, logp=res$logp)
datatemp2$brierdiff <- as.vector(brierdiff)


p3 <- ggplot(data=datatemp2, aes(x=logn, y=logp, fill = brierdiff)) + theme_bw() + geom_raster() +  
  labs(x="log(n)", y="log(p)") +
  theme(axis.title=element_text(size=13), legend.title=element_text(size=13), axis.text=element_text(size=10),
        legend.text=element_text(size=13)) +
  guides(fill = guide_colourbar(title="Mean difference\nbetween data set\nspecific brier\nvalues obtained\nfor RFextr5 and\nfor RF")) +
  scale_fill_viridis() 


quantiles <- c(0.1, 0.3, 0.5, 0.7, 0.9)
qus <- log(quantile(resultswide$n, probs=quantiles))

loesssurvres <- myloesssurf(resultswide$brier.RFextr5,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffRFextr5 <- loesssurvres$z

loesssurvres <- myloesssurf(resultswide$brier.RF,cbind(log(resultswide$n), log(resultswide$p)))
res <- data.frame(logn=loesssurvres$x, logp=loesssurvres$y)
brierdiffRF <- loesssurvres$z

quantiles2 <- paste("n = ", round(exp(sapply(1:length(qus), function(x) res$logn[which.min(abs(res$logn-qus[x]))]))), " (", round(100*quantiles), "% qu.)", sep="")

datatemp <- data.frame(logp=rep(res$logp, times=2*length(qus)), brier=unlist(lapply(1:length(qus), function(x) c(brierdiffRF[which.min(abs(res$logn-qus[x])),], brierdiffRFextr5[which.min(abs(res$logn-qus[x])),]))),
                       method=rep(rep(c("RF", "RFextr5"), each=length(res$logn)), times=length(qus)),
                       quantile=factor(rep(quantiles2, each=2*length(res$logn)), levels=quantiles2))

p4 <- ggplot(data=datatemp, aes(x=logp, y=brier)) + theme_bw() + geom_line(aes(color=method), size=0.1) + facet_wrap(~quantile, nrow=2) + 
  labs(x="log(p)", y="Data set specific Brier values") +
  theme(axis.title=element_text(size=13),
        strip.text = element_text(size=13), axis.text=element_text(size=10)) +
  scale_color_manual(values=c("red", "black")) + theme(legend.position="none")


pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/DataCharacteristics_RFextr5_brier.pdf", plot=pall, width=11, height=10)








# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot()

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$brierRF <- sapply(resultstemp$dataid, function(x) resultstemp2$brier[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=brierRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific Brier values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry_brier.pdf", plot=pall, width=11, height=10)







# Figure: Relationships between the mtry values selected by RF, RFextr1, 
# and RFextr5 and various quantities - excluding data set '312'.


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstempsafe <- resultstemp

resultstemp <- resultstemp[log(resultstemp$p) < 5.5,]

p1 <- ggplot(data=resultstemp, aes(x=method, y=paramopt/p)) + theme_bw() + 
  labs(x="Method", y="mtry/p") +
  theme(axis.title.y=element_text(size=15), axis.text.x=element_text(size=15),
        axis.title.x=element_blank(),
        axis.text.y=element_text(size=10)) +
  geom_boxplot()

datatemp <- data.frame(x=seq(log(min(resultstemp$p)), log(max(resultstemp$p)), length=200))
datatemp$y <- sqrt(exp(datatemp$x))/exp(datatemp$x)

p2 <- ggplot(data=resultstemp, aes(x=log(p), y=paramopt/p)) + theme_bw() + 
  labs(x="log(p)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE) + geom_line(data=datatemp, aes(x=x, y=y))

p3 <- ggplot(data=resultstemp, aes(x=log(n), y=paramopt/p)) + theme_bw() + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

resultstemp2 <- resultstemp[resultstemp$method=="RF",]
resultstemp$brierRF <- sapply(resultstemp$dataid, function(x) resultstemp2$brier[resultstemp2$dataid==x])

p4 <- ggplot(data=resultstemp, aes(x=brierRF, y=paramopt/p)) + theme_bw() + 
  labs(x="Data set specific Brier values obtained for RF", y="mtry/p") +
  theme(axis.title=element_text(size=15), axis.text=element_text(size=10), legend.position = "none") +
  geom_point(aes(color=method)) + geom_smooth(aes(color=method), se=FALSE)

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Mtry_2_brier.pdf", plot=pall, width=11, height=10)







# Figure: Relationships between the mtry values selected by RF, RFextr1, and RFextr5 
# and the logarithmized values of the sample size stratified brierording to the numbers 
# of covariates in the data sets.

quantile(resultswide$p, (1:9)/10)

mean(resultswide$p <= 5)
mean((resultswide$p > 5) & (resultswide$p <= 15))
mean(resultswide$p > 15)

sum(resultswide$p <= 5)
sum((resultswide$p > 5) & (resultswide$p <= 15))
sum(resultswide$p > 15)


resultstemp <- resultssum2[resultssum2$method!="DF",]
resultstemp$method <- droplevels(resultstemp$method)

resultstemp3 <- resultstemp
head(resultstemp3)
resultstemp3$psize <- "Small p"
resultstemp3$psize[resultstemp3$p > 5] <- "Middle p"
resultstemp3$psize[resultstemp3$p > 15] <- "Large p"
resultstemp3$psize <- factor(resultstemp3$psize, levels=c("Small p", "Middle p", "Large p"))

p <- ggplot(data=resultstemp3, aes(x=log(n), y=paramopt/p)) + theme_bw() + geom_point(aes(color=method)) + 
  labs(x="log(n)", y="mtry/p") +
  theme(axis.title=element_text(size=13), axis.text=element_text(size=10), strip.text = element_text(size=12), legend.position = "none") +
  geom_smooth(aes(color=method), se=FALSE) + facet_wrap(~ psize, nrow=1)
p

ggsave(file="./Online_Appendix_2/Results/Figures/InfluenceNstratified_brier.pdf", width=10, height=5)







# Figure: Relationships between the selected proptry values and various quantities.

resultstemp <- resultsall[resultsall$method=="DF",]
resultstemp <- ddply(resultstemp, .variables=c("dataid", "n", "p"), .fun=summarise, paramopt=median(paramopt))

resultswide$paramoptDF <- sapply(resultswide$dataid, function(x) resultstemp$paramopt[resultstemp$dataid==x])


table(resultswide$paramoptDF)


p1 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(n))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p2 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=log(p))) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry")

p3 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=brier.RF)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("Data set specific Brier values obtained for RF")

p4 <- ggplot(data=resultswide, aes(x=factor(paramoptDF), y=paramopt.RF/p)) + theme_bw() + 
  theme(axis.title=element_text(size=15), axis.text.x=element_text(size=14), axis.text.y=element_text(size=10)) +
  geom_boxplot() + scale_x_discrete(labels=c("0.05", "0.05 / 1", "1")) + xlab("proptry") + ylab("mtry/p")

pall <- grid.arrange(p1, p2, p3, p4, ncol = 2)

grid.draw(pall)

ggsave(file="./Online_Appendix_2/Results/Figures/Proptry_brier.pdf", plot=pall, width=11, height=10)















# Online Appendix 3: RF, RFextr1, and RFextr5: mean OOB prediction errors 
# obtained for the different mtry values per data set.


resultstemp <- resultsall
Resultstemp <- Results


Resultstemp <- Resultstemp[resultstemp$method!="DF"]
resultstemp <- resultstemp[resultstemp$method!="DF",]

resultstemp$seed <- NULL

reorderind <- order(resultstemp$dataid, resultstemp$method, resultstemp$cvind, resultstemp$cviter)

Resultstemp <- Resultstemp[reorderind]
resultstemp <- resultstemp[reorderind,]


dataidstemp <- unique(resultstemp$dataid); methodstemp <- unique(resultstemp$method)

tuningresults <- list()
count <- 1

for(i in seq(along=dataidstemp)) {
  
  for(j in seq(along=methodstemp)) {
    
    indtemp <- which(resultstemp$dataid==dataidstemp[i] & resultstemp$method==methodstemp[j])
    
    Resultstemp2 <- Resultstemp[indtemp]
    paramseqtemp <- Resultstemp2[[1]]$paramseq
    ooberrstemp <- rowMeans(sapply(Resultstemp2, function(x) x$ooberrs))
    
    tuningresults[[count]] <- list(dataid=rep(dataidstemp[i], times=length(paramseqtemp)), method=rep(methodstemp[j], times=length(paramseqtemp)), paramseq=paramseqtemp, ooberrs=ooberrstemp)
    
    count <- count + 1
    
  }
  
}

tuningres <- data.frame(dataid=unlist(sapply(tuningresults, function(x) x$dataid)),
                        method=unlist(sapply(tuningresults, function(x) x$method)),
                        paramseq=unlist(sapply(tuningresults, function(x) x$paramseq)),
                        ooberrs=unlist(sapply(tuningresults, function(x) x$ooberrs)))

tuningres$p <- sapply(tuningres$dataid, function(x) resultswide$p[resultswide$dataid==x])

tuningres <- tuningres[order(tuningres$p, tuningres$dataid),]
tuningres$dataid <- factor(as.character(tuningres$dataid), levels=unique(as.character(tuningres$dataid)))




plotinds <- rep(1:floor(length(unique(tuningres$dataid))/15), each=15)
plotinds <- c(plotinds, rep(max(plotinds)+1, times=length(unique(tuningres$dataid)) - length(plotinds)))

plotindsun <- unique(plotinds)

plist <- list()
library("scales")

for(i in seq(along=plotindsun)) {
  
  tuningrestemp <- tuningres[tuningres$dataid %in% unique(tuningres$dataid)[plotinds==plotindsun[i]],]  
  
  tuningrestemp$dataset <- sapply(tuningrestemp$dataid, function(x) {
    ids <- which(resultssum$dataid==x)[1]
    paste("ID: ", resultssum$dataid[ids], ", n = ", resultssum$n[ids], ", p = ", resultssum$p[ids], sep="")
  })
  levelstemp <- sapply(levels(tuningrestemp$dataid), function(x) {
    ids <- which(resultssum$dataid==x)[1]
    paste("ID: ", resultssum$dataid[ids], ", n = ", resultssum$n[ids], ", p = ", resultssum$p[ids], sep="")
  })
  tuningrestemp$dataset <- factor(tuningrestemp$dataset, levels=levelstemp)
  
  if(max(tuningrestemp$p) <= 7)
    plist[[i]] <- ggplot(data=tuningrestemp, aes(x=paramseq, y=ooberrs, color=method)) + theme_bw() + facet_wrap(~dataset, ncol=3, scales="free") + geom_point() + geom_line() +
    labs(x="mtry", y="OOB prediction error") + scale_x_continuous(breaks=1:10)
  else
    plist[[i]] <- ggplot(data=tuningrestemp, aes(x=paramseq, y=ooberrs, color=method)) + theme_bw() + facet_wrap(~dataset, ncol=3, scales="free") + geom_point() + geom_line() +
    labs(x="mtry", y="OOB prediction error") + scale_x_continuous(breaks=pretty_breaks())

}




pdf("./Online_Appendix_2/Results/Figures/OnlineAppendix3.pdf", width=9, height=10, onefile = TRUE)
for (i in seq(along=plist)) {
  grid.arrange(plist[[i]])
}
dev.off()











#  RFextr1: For each data set, calculate the differences between the mean OOB prediction error obtained 
# for the mtry value of sqrt(p) and the minimum mean OOB prediction error obtained for the mtry values larger than
# sqrt(p). See paragraph "RF, RFextr1, and RFextr5: selected mtry values" in the paper.


tuningrestemp <- tuningres[tuningres$p > 30,]

methodstemp <- unique(tuningrestemp$method)
dataidtemp <- unique(tuningrestemp$dataid)

methoddataidtemp <- expand.grid(method=methodstemp, dataid=dataidtemp, stringsAsFactors = FALSE)[,2:1]

library("nnet")

improvements <- apply(methoddataidtemp, 1, function(x) {
  
  tuningrestemp2 <- tuningrestemp[tuningrestemp$dataid==x[1] & tuningrestemp$method==x[2],]
  
  ps <- c(max(tuningrestemp2$paramseq[tuningrestemp2$paramseq <= sqrt(max(tuningrestemp2$paramseq))]),
          tuningrestemp2$paramseq[tuningrestemp2$paramseq > floor(sqrt(max(tuningrestemp2$paramseq)))][which.is.max(-tuningrestemp2$ooberrs[tuningrestemp2$paramseq > floor(sqrt(max(tuningrestemp2$paramseq)))])])
  
  oobs <- sapply(ps, function(x) tuningrestemp2$ooberrs[tuningrestemp2$paramseq==x])
  
  return(oobs[1] - oobs[2])
  
})

methoddataidtemp$improvement <- improvements


methoddataidtemp2 <- methoddataidtemp[methoddataidtemp$method=="RFextr1",]
methoddataidtemp2 <- methoddataidtemp2[order(methoddataidtemp2$improvement, decreasing=TRUE),]

methoddataidtemp2[methoddataidtemp2$improvement > 0.02,]

# --> For four data sets this difference was larger than 0.02.

